@@ -116,7 +116,7 @@ test_that("distributions", {
 
     ## Multivariate distribution
     m <- lvm()
-    rmr <- function(n,rho,...) rmvn(n,sigma=diag(2)*(1-rho)+rho)
+    rmr <- function(n,rho,...) rmvn0(n,sigma=diag(2)*(1-rho)+rho)
     distribution(m,~y1+y2,rho=0.9) <- rmr
     testthat::expect_equivalent(c("y1","y2"),colnames(d <- sim(m,5)))
 
@@ -163,8 +163,7 @@ test_that("eventTime", {
     d <- sim(m,100)
     testthat::expect_equivalent((d$time<d$cens)*1L,d$status)
 
-    ## TODO
-    plot(m)
+    ## TODO: plot(m)
     testthat::expect_output(print(m),"Event History Model")
 
     ## Time varying effect
